==> unicore-uvos-server-1.5.1-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/WSQueryHistoryImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 7, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import java.util.Date;
import java.util.List;

import javax.jws.WebService;

import org.apache.log4j.Logger;

import pl.edu.icm.unicore.uvos.api.Attribute;
import pl.edu.icm.unicore.uvos.api.Element;
import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.ModificationEvent;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.engine.api.UVOSQueryHistoryInterface;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.WSQueryHistoryInterface;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.XMLBeansMapper;
import xmlbeans.pl.edu.icm.uvos.internal.AttributesListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.ElementsListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.ElementDocument;
import xmlbeans.pl.edu.icm.uvos.internal.GroupDocument;
import xmlbeans.pl.edu.icm.uvos.internal.GroupsListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentitiesListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentityDocument;
import xmlbeans.pl.edu.icm.uvos.internal.ModificationEventListDocument;

/**
 * @author K. Benedyczak
 */
@WebService(endpointInterface="pl.edu.icm.unicore.uvos.wsapi.WSQueryHistoryInterface")
public class WSQueryHistoryImpl implements WSQueryHistoryInterface
{
	private static final Logger log = Logger.getLogger(WSQueryHistoryImpl.class);
	private UVOSQueryHistoryInterface voQuery;
	private Authenticator authenticator;

	public WSQueryHistoryImpl(UVOSQueryHistoryInterface voQuery, Authenticator auth) throws InternalException
	{
		this.voQuery = voQuery;
		this.authenticator = auth;
	}

	public boolean areEquivalent(IdentityDocument arg0, IdentityDocument arg1, Date when) 
	throws UVOSFault
	{
		try
		{
			log.debug("areEquivalent invoked");
			authenticator.authenticate();
			return voQuery.areEquivalent(
					XMLBeansMapper.map2APIIdentity(arg0), 
					XMLBeansMapper.map2APIIdentity(arg1), when);
		} catch (UVOSException e)
		{
			log.info("Error invoking areEquivalent: " + e);
			throw new UVOSFault(e);
		}
	}

	public AttributesListDocument getAttributes(ElementDocument owner, String attribute,
			boolean arg1, boolean includeScoped, boolean includeImplied, Date when) 
		throws UVOSFault
	{
		try
		{
			log.debug("getAttributes invoked");
			authenticator.authenticate();
			List<Attribute> raw = null;
			raw = voQuery.getAttributes(
					XMLBeansMapper.map2APIElement(owner), 
					attribute, arg1, includeScoped, 
					includeImplied, when);
			return XMLBeansMapper.map2XMLAttributesList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAttributes: " + e);
			throw new UVOSFault(e);
		}
	}

	public IdentitiesListDocument getAllEquivalents(IdentityDocument arg0, Date when) 
	throws UVOSFault
	{
		try
		{
			log.debug("getAllEquivalents invoked");
			authenticator.authenticate();
			List<Identity> raw = null;
			raw = voQuery.getAllEquivalents(
					XMLBeansMapper.map2APIIdentity(arg0), when);

			return XMLBeansMapper.map2XMLIdentitiesList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAllEquivalents: " + e);
			throw new UVOSFault(e);
		}
	}

	public GroupsListDocument getAllGroups(IdentityDocument arg0, boolean implied,
			Date when) 
		throws UVOSFault
	{
		try
		{
			log.debug("getAllGroups invoked");
			authenticator.authenticate();
			List<Group> raw = null;
			raw = voQuery.getAllGroups(
					XMLBeansMapper.map2APIIdentity(arg0), 
					implied, when);

			return XMLBeansMapper.map2XMLList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAllGroups: " + e);
			throw new UVOSFault(e);
		}
	}

	public IdentitiesListDocument getAllIdentities(Date when) throws UVOSFault
	{
		try
		{
			log.debug("getAllIdentities invoked");
			authenticator.authenticate();
			List<Identity> raw = null;
			raw = voQuery.getAllIdentities(when);

			return XMLBeansMapper.map2XMLIdentitiesList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAllIdentities: " + e);
			throw new UVOSFault(e);
		}
	}

	public ElementsListDocument getGroupContent(GroupDocument arg0, Date when) 
		throws UVOSFault
	{
		try
		{
			log.debug("getGroupContent invoked");
			authenticator.authenticate();
			List<Element> raw = null;
			raw = voQuery.getGroupContent(XMLBeansMapper.map2APIGroup(arg0), 
					when);
			return XMLBeansMapper.map2XMLElementsList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getGroupContent: " + e);
			throw new UVOSFault(e);
		}
	}

	public boolean isMember(IdentityDocument arg0, GroupDocument arg1, boolean arg2,
			Date when) 
	throws UVOSFault
	{
		try
		{
			log.debug("isMember invoked");
			authenticator.authenticate();
			return voQuery.isMember(XMLBeansMapper.map2APIIdentity(arg0), 
						XMLBeansMapper.map2APIGroup(arg1), arg2, 
						when);
		} catch (UVOSException e)
		{
			log.info("Error invoking isMember: " + e);
			throw new UVOSFault(e);
		}
	}
	
	public ModificationEventListDocument getHistoryEvents(Date from, Date to, 
			int categoryFilter, int typeFilter, 
			boolean fillDetails) 
		throws UVOSFault
	{
		try
		{
			log.debug("getHistoryEvents invoked");
			authenticator.authenticate();
			List<ModificationEvent> raw = voQuery.getHistoryEvents(from, to, 
					categoryFilter,	typeFilter, fillDetails);
			return XMLBeansMapper.map2XMLModificationEventList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getHistoryEvents: " + e);
			throw new UVOSFault(e);
		}
		
	}
}

==> unicore-uvos-server-1.6.0-0.src.tar.gz: src/main/java/pl/edu/icm/unicore/uvos/server/WSQueryHistoryImpl.java <==
/*
 * Copyright (c) 2007, 2008 ICM Uniwersytet Warszawski All rights reserved.
 * See LICENCE file for licencing information.
 *
 * Created on Aug 7, 2007
 * Author: K. Benedyczak <golbi@mat.umk.pl>
 */

package pl.edu.icm.unicore.uvos.server;

import java.util.Date;
import java.util.List;

import javax.jws.WebService;

import org.apache.log4j.Logger;

import eu.unicore.util.Log;

import pl.edu.icm.unicore.uvos.api.Attribute;
import pl.edu.icm.unicore.uvos.api.Element;
import pl.edu.icm.unicore.uvos.api.Group;
import pl.edu.icm.unicore.uvos.api.Identity;
import pl.edu.icm.unicore.uvos.api.ModificationEvent;
import pl.edu.icm.unicore.uvos.api.exceptions.InternalException;
import pl.edu.icm.unicore.uvos.api.exceptions.UVOSException;
import pl.edu.icm.unicore.uvos.engine.api.UVOSQueryHistoryInterface;
import pl.edu.icm.unicore.uvos.server.idresolver.Authenticator;
import pl.edu.icm.unicore.uvos.util.UVOSServerProperties;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.UVOSFault;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.WSQueryHistoryInterface;
import pl.edu.icm.unicore.uvos.wsapi.xmlbeans.XMLBeansMapper;
import xmlbeans.pl.edu.icm.uvos.internal.AttributesListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.ElementsListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.ElementDocument;
import xmlbeans.pl.edu.icm.uvos.internal.GroupDocument;
import xmlbeans.pl.edu.icm.uvos.internal.GroupsListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentitiesListDocument;
import xmlbeans.pl.edu.icm.uvos.internal.IdentityDocument;
import xmlbeans.pl.edu.icm.uvos.internal.ModificationEventListDocument;

/**
 * @author K. Benedyczak
 */
@WebService(endpointInterface="pl.edu.icm.unicore.uvos.wsapi.WSQueryHistoryInterface")
public class WSQueryHistoryImpl implements WSQueryHistoryInterface
{
	private static final Logger log = Log.getLogger(UVOSServerProperties.LOG_PFX, WSQueryHistoryImpl.class);
	private UVOSQueryHistoryInterface voQuery;
	private Authenticator authenticator;

	public WSQueryHistoryImpl(UVOSQueryHistoryInterface voQuery, Authenticator auth) throws InternalException
	{
		this.voQuery = voQuery;
		this.authenticator = auth;
	}

	public boolean areEquivalent(IdentityDocument arg0, IdentityDocument arg1, Date when) 
	throws UVOSFault
	{
		try
		{
			log.debug("areEquivalent invoked");
			authenticator.authenticate();
			return voQuery.areEquivalent(
					XMLBeansMapper.map2APIIdentity(arg0), 
					XMLBeansMapper.map2APIIdentity(arg1), when);
		} catch (UVOSException e)
		{
			log.info("Error invoking areEquivalent: " + e);
			throw new UVOSFault(e);
		}
	}

	public AttributesListDocument getAttributes(ElementDocument owner, String attribute,
			boolean arg1, boolean includeScoped, boolean includeImplied, Date when) 
		throws UVOSFault
	{
		try
		{
			log.debug("getAttributes invoked");
			authenticator.authenticate();
			List<Attribute> raw = null;
			raw = voQuery.getAttributes(
					XMLBeansMapper.map2APIElement(owner), 
					attribute, arg1, includeScoped, 
					includeImplied, when);
			return XMLBeansMapper.map2XMLAttributesList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAttributes: " + e);
			throw new UVOSFault(e);
		}
	}

	public IdentitiesListDocument getAllEquivalents(IdentityDocument arg0, Date when) 
	throws UVOSFault
	{
		try
		{
			log.debug("getAllEquivalents invoked");
			authenticator.authenticate();
			List<Identity> raw = null;
			raw = voQuery.getAllEquivalents(
					XMLBeansMapper.map2APIIdentity(arg0), when);

			return XMLBeansMapper.map2XMLIdentitiesList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAllEquivalents: " + e);
			throw new UVOSFault(e);
		}
	}

	public GroupsListDocument getAllGroups(IdentityDocument arg0, boolean implied,
			Date when) 
		throws UVOSFault
	{
		try
		{
			log.debug("getAllGroups invoked");
			authenticator.authenticate();
			List<Group> raw = null;
			raw = voQuery.getAllGroups(
					XMLBeansMapper.map2APIIdentity(arg0), 
					implied, when);

			return XMLBeansMapper.map2XMLList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAllGroups: " + e);
			throw new UVOSFault(e);
		}
	}

	public IdentitiesListDocument getAllIdentities(Date when) throws UVOSFault
	{
		try
		{
			log.debug("getAllIdentities invoked");
			authenticator.authenticate();
			List<Identity> raw = null;
			raw = voQuery.getAllIdentities(when);

			return XMLBeansMapper.map2XMLIdentitiesList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getAllIdentities: " + e);
			throw new UVOSFault(e);
		}
	}

	public ElementsListDocument getGroupContent(GroupDocument arg0, Date when) 
		throws UVOSFault
	{
		try
		{
			log.debug("getGroupContent invoked");
			authenticator.authenticate();
			List<Element> raw = null;
			raw = voQuery.getGroupContent(XMLBeansMapper.map2APIGroup(arg0), 
					when);
			return XMLBeansMapper.map2XMLElementsList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getGroupContent: " + e);
			throw new UVOSFault(e);
		}
	}

	public boolean isMember(IdentityDocument arg0, GroupDocument arg1, boolean arg2,
			Date when) 
	throws UVOSFault
	{
		try
		{
			log.debug("isMember invoked");
			authenticator.authenticate();
			return voQuery.isMember(XMLBeansMapper.map2APIIdentity(arg0), 
						XMLBeansMapper.map2APIGroup(arg1), arg2, 
						when);
		} catch (UVOSException e)
		{
			log.info("Error invoking isMember: " + e);
			throw new UVOSFault(e);
		}
	}
	
	public ModificationEventListDocument getHistoryEvents(Date from, Date to, 
			int categoryFilter, int typeFilter, 
			boolean fillDetails) 
		throws UVOSFault
	{
		try
		{
			log.debug("getHistoryEvents invoked");
			authenticator.authenticate();
			List<ModificationEvent> raw = voQuery.getHistoryEvents(from, to, 
					categoryFilter,	typeFilter, fillDetails);
			return XMLBeansMapper.map2XMLModificationEventList(raw);
		} catch (UVOSException e)
		{
			log.info("Error invoking getHistoryEvents: " + e);
			throw new UVOSFault(e);
		}
		
	}
}
